@@ -22,9 +22,14 @@ use Filesys::POSIX::Userland ();
 
 use Filesys::POSIX::Error qw(throw);
 
-use Carp qw(confess);
+use Carp qw/confess/;
 
-our $VERSION = '0.9.15';
+our $AUTOLOAD;
+
+BEGIN {
+    use Exporter ();
+    our $VERSION = '0.9.15_0001';
+}
 
 =head1 NAME
 
@@ -783,11 +788,6 @@ Lists the requirements for writing modules that act as directory structures.
 
 Lists the requirements for writing modules that act as inodes.
 
-=item L<Filesys::POSIX::Module>
-
-Provides an interface for loading methods from modules that extend
-Filesys::POSIX.
-
 =back
 
 =head1 INTERNALS
